@@ -2,6 +2,7 @@ __author__ = "Jonas Geduldig"
 __date__ = "June 7, 2013"
 __license__ = "MIT"
 
+from BearerAuth import BearerAuth
 from .constants import *
 import json
 import requests
@@ -11,8 +12,17 @@ from requests_oauthlib import OAuth1
 class TwitterAPI(object):	
 	"""Access REST API or Streaming API resources."""
 	
-	def __init__(self, consumer_key, consumer_secret, access_token_key, access_token_secret):
-		self.auth = OAuth1(consumer_key, consumer_secret, access_token_key, access_token_secret)
+	def __init__(self, consumer_key=None, consumer_secret=None, access_token_key=None, access_token_secret=None, auth_type="oAuth1"):
+		"""Initialize with your Twitter application credentials"""
+		if auth_type is "oAuth1":
+			if not all([consumer_key, consumer_secret, access_token_key, access_token_secret]):
+				raise Exception("Missing authentication parameter.")
+			self.auth = OAuth1(consumer_key, consumer_secret, access_token_key, access_token_secret)
+		elif auth_type is "oAuth2":
+			if not all([consumer_key, consumer_secret]):
+				raise Exception("Missing authentication parameter.")
+			token_url = '%s://%s.%s/%s' % (PROTOCOL, REST_SUBDOMAIN, DOMAIN, OAUTH2_TOKEN_ENDPOINT)
+			self.auth = BearerAuth(token_url, consumer_key, consumer_secret)
 				
 	def _prepare_url(self, subdomain, path):
 		return '%s://%s.%s/%s/%s.json' % (PROTOCOL, subdomain, DOMAIN, VERSION, path)
@@ -62,6 +72,10 @@ class TwitterResponse(object):
 		self.response = response
 		self.stream = stream
 
+	@property
+	def headers(self):
+		return self.response.headers
+
 	@property
 	def status_code(self):
 		return self.response.status_code
