@@ -23,7 +23,7 @@ VERSION = '1.1'
 
 USER_AGENT = 'python-TwitterAPI.cli.py'
 
-STREAMING_SOCKET_TIMEOUT = 90 # 90 seconds per Twitter's recommendation
+STREAMING_SOCKET_TIMEOUT = 90  # 90 seconds per Twitter's recommendation
 
 STREAMING_ENDPOINTS = {
 		# resource:                                ( subdomain )
@@ -39,15 +39,17 @@ REST_SUBDOMAIN = 'api'
 
 REST_SOCKET_TIMEOUT = 5
 
+OAUTH2_TOKEN_ENDPOINT = 'oauth2/token'
+
 REST_ENDPOINTS = {
 		# resource:                                ( method )
 
-		'statuses/destroy/:PARAM':                 ('POST',), # ID
+		'statuses/destroy/:PARAM':                 ('POST',),  # ID
 		'statuses/home_timeline':                  ('GET',),
 		'statuses/mentions_timeline':              ('GET',),
 		'statuses/oembed':                         ('GET',),
 		'statuses/retweets_of_me':                 ('GET',),
-		'statuses/retweet/:PARAM':                 ('POST',), # ID
+		'statuses/retweet/:PARAM':                 ('POST',),  # ID
 		'statuses/retweets/:PARAM':                ('GET',),  # ID
 		'statuses/show/:PARAM':                    ('GET',),  # ID
 		'statuses/user_timeline':                  ('GET',),
@@ -127,7 +129,7 @@ REST_ENDPOINTS = {
 		'lists/update':                            ('POST',),
 
 		'saved_searches/create':                   ('POST',),
-		'saved_searches/destroy/:PARAM':           ('POST',), # ID
+		'saved_searches/destroy/:PARAM':           ('POST',),  # ID
 		'saved_searches/list':                     ('GET',),
 		'saved_searches/show/:PARAM':              ('GET',),  # ID
 
@@ -141,11 +143,6 @@ REST_ENDPOINTS = {
 		'trends/closest':                          ('GET',),
 		'trends/place':                            ('GET',),
 
-		'oauth/access_token':                      ('POST',),
-		'oauth/authenticate':                      ('GET',),
-		'oauth/authorize':                         ('GET',),
-		'oauth/request_token':                     ('POST',),
-
 		'help/configuration':                      ('GET',),
 		'help/languages':                          ('GET',),
 		'help/privacy':                            ('GET',),
